@@ -19,90 +19,90 @@ odl = list(
 
 # openstreetmap.org
 osm = list(long=list(
-      	latex=paste(
-          	', cartography is licensed as ',
-          	'\\href{http://creativecommons.org/licenses/by-sa/2.0}{CC BY-SA}.',
-          	sep=''
-      	),
-      	markdown=paste(
-          	', cartography is licensed as [CC BY-SA](http://creativecommons.org/licenses/by-sa/2.0).',
-          	sep=''
-      	),
-      	html=paste(
-          	', cartography is licensed as',
-          	' <a href="http://creativecommons.org/licenses/by-sa/2.0">CC BY-SA</a>.',
-          	sep=''
-      	),
-      	text =paste(
-          	', cartography is licensed as CC BY-SA (see www.openstreetmap.org/copyright).',
-          	sep=''
-      	)
-  	),
-  	short=list(
-      	latex='\\copyright \\href{http://openstreetmap.org/copyright}{OpenStreetMap}',
-      	markdown='&copy; [OpenStreetMap](http://openstreetmap.org/copyright)',
-      	html= '&copy; <a href="http://openstreetmap.org/copyright">OpenStreetMap</a>',
-      	text='copyright OpenStreetMap.org'
+        latex=paste(
+            ', cartography is licensed as ',
+            '\\href{http://creativecommons.org/licenses/by-sa/2.0}{CC BY-SA}.',
+            sep=''
+        ),
+        markdown=paste(
+            ', cartography is licensed as [CC BY-SA](http://creativecommons.org/licenses/by-sa/2.0).',
+            sep=''
+        ),
+        html=paste(
+            ', cartography is licensed as',
+            ' <a href="http://creativecommons.org/licenses/by-sa/2.0">CC BY-SA</a>.',
+            sep=''
+        ),
+        text =paste(
+            ', cartography is licensed as CC BY-SA (see www.openstreetmap.org/copyright).',
+            sep=''
+        )
+    ),
+    short=list(
+        latex='\\copyright \\href{http://openstreetmap.org/copyright}{OpenStreetMap}',
+        markdown='&copy; [OpenStreetMap](http://openstreetmap.org/copyright)',
+        html= '&copy; <a href="http://openstreetmap.org/copyright">OpenStreetMap</a>',
+        text='copyright OpenStreetMap.org'
     )
 )
 
 sputnik = list(
-		long=list(
-      	latex='\\href{http://corp.sputnik.ru/maps}{corp.sputnik.ru/maps}',
-      	markdown='[corp.sputnik.ru/maps](http://corp.sputnik.ru/maps)',
-      	html=' <a href="http://corp.sputnik.ru/maps">corp.sputnik.ru/maps</a>.',
-      	text ='http://corp.sputnik.ru/maps'
-  	)		
+    long=list(
+        latex='\\href{http://corp.sputnik.ru/maps}{corp.sputnik.ru/maps}',
+        markdown='[corp.sputnik.ru/maps](http://corp.sputnik.ru/maps)',
+        html=' <a href="http://corp.sputnik.ru/maps">corp.sputnik.ru/maps</a>.',
+        text ='http://corp.sputnik.ru/maps'
+    )		
 )
 sputnik$short = sputnik$long
 
 # open govt licence canada
 nrcan = list(long=list(
-      	latex=paste(
-          	'Cartography by \\href{http://www.nrcan.gc.ca/earth-sciences/geography/topographic-information/free-data-geogratis/geogratis-web-services/17216}',
-						'{The Canada Base Map --- Transportation (CBMT) web mapping services',
-						' of the Earth Sciences Sector (ESS) at Natural Resources Canada (NRCan)}',
-          	' licensed as the ',
-						'\\href{http://open.canada.ca/en/open-government-licence-canada}',
-						'{Open Government Licence --- Canada}.',
-          	sep=''
-      	),
-      	markdown=
-						paste(
-          			'Cartography by ',
-								'[The Canada Base Map - Transportation (CBMT) web mapping services',
-								' of the Earth Sciences Sector (ESS) at Natural Resources Canada (NRCan)]',
-								'(http://www.nrcan.gc.ca/earth-sciences/geography/topographic-information/free-data-geogratis/geogratis-web-services/17216)',
-          			' licensed as the ',
-								'[Open Government Licence - Canada]',
-								'(http://open.canada.ca/en/open-government-licence-canada).',
-          			sep=''
-      			),
-      	html=paste(
-          	'Cartography by <a href="http://www.nrcan.gc.ca/earth-sciences/geography/topographic-information/free-data-geogratis/geogratis-web-services/17216">',
-						'The Canada Base Map - Transportation (CBMT) web mapping services',
-						' of the Earth Sciences Sector (ESS) at Natural Resources Canada (NRCan)</a>',
-          	' licensed as the ',
-						'<a href="http://open.canada.ca/en/open-government-licence-canada">',
-						'Open Government Licence - Canada</a>.',
-          	sep=''
-      	),
-      	text =paste(
-          	'Cartography by ',
-						'The Canada Base Map - Transportation (CBMT) web mapping services',
-						' of the Earth Sciences Sector (ESS) at Natural Resources Canada (NRCan) ',
-						'(www.nrcan.gc.ca/earth-sciences/geography/topographic-information)',
-          	' licensed as the ',
-						'Open Government Licence - Canada',
-						' (open.canada.ca/en/open-government-licence-canada).',
-          	sep=''
-  			)
-		),
-  	short=list(
-      	latex='\\href{http://www.nrcan.gc.ca}{Natural Resources Canada}',
-      	markdown='[Natural Resources Canada](http://www.nrcan.gc.ca)',
-      	html= '&copy; <a href="http://www.nrcan.gc.ca">Natural Resources Canada"</a>',
-      	text='Natural Resources Canada'
+        latex=paste(
+            'Cartography by \\href{http://www.nrcan.gc.ca/earth-sciences/geography/topographic-information/free-data-geogratis/geogratis-web-services/17216}',
+            '{The Canada Base Map --- Transportation (CBMT) web mapping services',
+            ' of the Earth Sciences Sector (ESS) at Natural Resources Canada (NRCan)}',
+            ' licensed as the ',
+            '\\href{http://open.canada.ca/en/open-government-licence-canada}',
+            '{Open Government Licence --- Canada}.',
+            sep=''
+        ),
+        markdown=
+            paste(
+                'Cartography by ',
+                '[The Canada Base Map - Transportation (CBMT) web mapping services',
+                ' of the Earth Sciences Sector (ESS) at Natural Resources Canada (NRCan)]',
+                '(http://www.nrcan.gc.ca/earth-sciences/geography/topographic-information/free-data-geogratis/geogratis-web-services/17216)',
+                ' licensed as the ',
+                '[Open Government Licence - Canada]',
+                '(http://open.canada.ca/en/open-government-licence-canada).',
+                sep=''
+            ),
+        html=paste(
+            'Cartography by <a href="http://www.nrcan.gc.ca/earth-sciences/geography/topographic-information/free-data-geogratis/geogratis-web-services/17216">',
+            'The Canada Base Map - Transportation (CBMT) web mapping services',
+            ' of the Earth Sciences Sector (ESS) at Natural Resources Canada (NRCan)</a>',
+            ' licensed as the ',
+            '<a href="http://open.canada.ca/en/open-government-licence-canada">',
+            'Open Government Licence - Canada</a>.',
+            sep=''
+        ),
+        text =paste(
+            'Cartography by ',
+            'The Canada Base Map - Transportation (CBMT) web mapping services',
+            ' of the Earth Sciences Sector (ESS) at Natural Resources Canada (NRCan) ',
+            '(www.nrcan.gc.ca/earth-sciences/geography/topographic-information)',
+            ' licensed as the ',
+            'Open Government Licence - Canada',
+            ' (open.canada.ca/en/open-government-licence-canada).',
+            sep=''
+        )
+    ),
+    short=list(
+        latex='\\href{http://www.nrcan.gc.ca}{Natural Resources Canada}',
+        markdown='[Natural Resources Canada](http://www.nrcan.gc.ca)',
+        html= '&copy; <a href="http://www.nrcan.gc.ca">Natural Resources Canada"</a>',
+        text='Natural Resources Canada'
     )
 )
 
@@ -148,17 +148,17 @@ osmLandscape$long$html = gsub("cartography[[:print:]]+$",
 
 mapquest = mapquestSat = list(
     short=list(
-      	latex='Tiles courtesy of \\href{http://www.mapquest.com}{MapQuest}',
-      	text='Tiles courtesy of MapQuest(www.mapquest.com)',
-      	markdown='Tiles courtesy of [MapQuest](http://www.mapquest.com)',
-      	html='Tiles courtesy of <a href="http://www.mapquest.com">MapQuest</a>'
+        latex='Tiles courtesy of \\href{http://www.mapquest.com}{MapQuest}',
+        text='Tiles courtesy of MapQuest(www.mapquest.com)',
+        markdown='Tiles courtesy of [MapQuest](http://www.mapquest.com)',
+        html='Tiles courtesy of <a href="http://www.mapquest.com">MapQuest</a>'
     ),
     long=list()
 )
 for(D in names(mapquest$short)){
   mapquest$long[[D]] = paste(
       mapquest$short[[D]],
-			odl[[D]],
+      odl[[D]],
       sep='. ')
   mapquestSat$long[[D]] = paste(
       mapquest$short[[D]],
@@ -173,25 +173,25 @@ stamen = stamenToner = list(
         markdown='&copy; [Stamen Design](http://stamen.com)',
         html= '&copy; <a href="http://stamen.com">Stamen Design</a>',
         text='copyright Stamen Design'
-  	),
+    ),
     long=list(
-      	html=paste(
-          	'Map tiles by <a href="http://stamen.com">Stamen Design</a>',
-          	'under <a href="http://creativecommons.org/licenses/by/3.0">CC BY 3.0</a>.'
+        html=paste(
+            'Map tiles by <a href="http://stamen.com">Stamen Design</a>',
+            'under <a href="http://creativecommons.org/licenses/by/3.0">CC BY 3.0</a>.'
         ),
-      	latex=paste(
-          	'Map tiles by \\href{http://stamen.com}{Stamen Design}',
-          	'under \\href{http://creativecommons.org/licenses/by/3.0}{CC BY 3.0}.'
+        latex=paste(
+            'Map tiles by \\href{http://stamen.com}{Stamen Design}',
+            'under \\href{http://creativecommons.org/licenses/by/3.0}{CC BY 3.0}.'
         ),
-      	markdown=paste(
-          	'Map tiles by [Stamen Design](http://stamen.com)',
-          	'under [CC BY 3.0](http://creativecommons.org/licenses/by/3.0).'
+        markdown=paste(
+            'Map tiles by [Stamen Design](http://stamen.com)',
+            'under [CC BY 3.0](http://creativecommons.org/licenses/by/3.0).'
         ),
-      	text=paste(
-          	'Map tiles by Stamen Design',
-          	'under CC BY 3.0 (creativecommons.org/licenses/by/3.0).'
+        text=paste(
+            'Map tiles by Stamen Design',
+            'under CC BY 3.0 (creativecommons.org/licenses/by/3.0).'
         )
-  	)
+    )
 )
 for(D in names(stamenToner$long)){
   stamenToner$long[[D]] = paste(
@@ -213,8 +213,8 @@ for(D in names(stamen$long)){
 thunderforest = maptoolkit = waze=cartodb = stamenToner
 for(D in names(cartodb$long)){
   for(D2 in c('long','short')){
-  	cartodb[[D2]][[D]] = gsub(
-      	"Stamen Design", "CartoDB",
+    cartodb[[D2]][[D]] = gsub(
+        "Stamen Design", "CartoDB",
         cartodb[[D2]][[D]]
     )
     cartodb[[D2]][[D]] = gsub(
@@ -237,15 +237,15 @@ for(D in names(cartodb$long)){
         "Stamen Design", "Toursprung GmbH",
         maptoolkit[[D2]][[D]]
     )
-		thunderforest[[D2]][[D]] = gsub(
-				"stamen.com", "thunderforest.com",
-				thunderforest[[D2]][[D]]
-		)
-		thunderforest[[D2]][[D]] = gsub(
-				"Stamen Design", "Thunderforest",
-				thunderforest[[D2]][[D]]
-		)
-		
+    thunderforest[[D2]][[D]] = gsub(
+        "stamen.com", "thunderforest.com",
+        thunderforest[[D2]][[D]]
+    )
+    thunderforest[[D2]][[D]] = gsub(
+        "Stamen Design", "Thunderforest",
+        thunderforest[[D2]][[D]]
+    )
+    
   }
   maptoolkit$long[[D]] = paste(
       maptoolkit$short[[D]],
@@ -259,7 +259,7 @@ for(D in names(cartodb$long)){
 esriAttribution = function(name) {
   
   #'http://downloads2.esri.com/ArcGISOnline/docs/tou_summary.pdf'
-	
+  
   long=list(
       'esri'='Esri, HERE, DeLorme, USGS, Intermap, increment P Corp., NRCAN, Esri Japan, METI, Esri China (Hong Kong), Esri (Thailand), TomTom, MapmyIndia, copyright OpenStreetMap contributors, and the GIS User Community',
       'esri-grey' = 'Esri, HERE, DeLorme, MapmyIndia, copyright OpenStreetMap contributors, and the GIS user community',
@@ -289,11 +289,11 @@ esriAttribution = function(name) {
   
   weburl = gsub("/tile/?$", '', name)
   
-	
-	
-	
-	long = long[names(name)]
-	
+  
+  
+  
+  long = long[names(name)]
+  
   list(long=list(
           latex=paste(
               gsub("copyright", "\\\\copyright", long), 
@@ -326,16 +326,23 @@ esriAttribution = function(name) {
           markdown = paste('&copy;','[', short,'](',
               weburl, ')',sep=''),
           html = paste('&copy; <a href=\"', weburl, 
-          		'\">', short , '</a>',sep=''),
+              '\">', short , '</a>',sep=''),
           text=paste('copyright', short)
       )
   )
   
 }
 
-openmapAttribution = function(name, type=c('text','latex','markdown','html'), short=FALSE) {
-	
+openmapAttribution = function(name, type=c('text','latex','markdown','html','auto'), short=FALSE) {
+  
   type = type[1]
+  if(type == 'auto') {
+    if(all(unlist(mget("mdToTex", envir=.GlobalEnv, ifnotfound=FALSE)) == TRUE ) ) {
+      type = 'latex'  
+    } else {
+      type ='markdown'
+    }
+  }
   
   if(!is.null(names(name))){
     name = names(name)
@@ -346,11 +353,11 @@ openmapAttribution = function(name, type=c('text','latex','markdown','html'), sh
   name = unique(gsub("Red$|Green$|Blue$|Trans$", "", name))
   result = c()
   for(D in name){
-		
-		if(length(grep('^nrcan', D))) {
-			result[D] = nrcan[[shortlong]][[type]]
-			
-		} else if(length(grep(
+    
+    if(length(grep('^nrcan', D))) {
+      result[D] = nrcan[[shortlong]][[type]]
+      
+    } else if(length(grep(
             "^osm|wikimedia|hyda|opentopomap|openstreetmap|historical|bw.mapnik", 
             D))){        # openstreetmap
       result[D] = osm[[shortlong]][[type]]
@@ -386,6 +393,6 @@ openmapAttribution = function(name, type=c('text','latex','markdown','html'), sh
     } else {
       result[D] = NA
     }
-	} # loop through name
-	result
+  } # loop through name
+  result
 }
