@@ -1,4 +1,5 @@
 #+ setup
+options("rgdal_show_exportToProj4_warnings"="none") 
 library('mapmisc')
 
 if(!exists('mapmiscCachePath'))
@@ -22,22 +23,26 @@ getOption("mapmiscCacheReadOnly")
 #+ themaps, fig.cap='some maps', fig.subcap = c('projectable region', 'projected, with bg','projected, with world countries','projectable madagascar','madagascar')
 Spackages = c('rgdal', 'rgeos', 'geosphere')
 
-if(all(unlist(mapply(requireNamespace, package=Spackages, MoreArgs=list(quietly=TRUE))))){
+#if(all(unlist(mapply(requireNamespace, package=Spackages, MoreArgs=list(quietly=TRUE))))){
 #	library('rgdal')
 
-	data("worldMap")
+		data("worldMap")
 
-	world = spTransform(worldMap, crsLL)
-	country='Japan'
-	Dcountry = grep(country, world$NAME)
-	x=world[Dcountry,]
+		world = spTransform(worldMap, crsLL)
+		country='Japan'
+		Dcountry = grep(country, world$NAME)
+		x=world[Dcountry,]
 
-	myCrsO = moll(x)
+		myCrsO = moll(x)
 
  plot(world)
  plot(attributes(myCrsO)$regionLL, 
  	border='red', col='#0000FF10', add=TRUE)
- 
+#}
+
+
+if(all(unlist(mapply(requireNamespace, package=Spackages, MoreArgs=list(quietly=TRUE))))){
+
  myMap = openmap(myCrsO, zoom=1, fact=2)
  map.new(myMap)
  plot(myMap, add=TRUE)
@@ -54,6 +59,8 @@ if(all(unlist(mapply(requireNamespace, package=Spackages, MoreArgs=list(quietly=
 	
 	gridlinesWrap(myCrsO, lty=2, col='orange')
 	
+}
+if(all(unlist(mapply(requireNamespace, package=Spackages, MoreArgs=list(quietly=TRUE))))){
 
  country='Madagascar'
 	Dcountry  = grep(country, world$NAME)
@@ -76,6 +83,8 @@ if(all(unlist(mapply(requireNamespace, package=Spackages, MoreArgs=list(quietly=
 	
 	gridlinesWrap(crs=xTcrop, lty=2, col='red')
 
+}
+if(all(unlist(mapply(requireNamespace, package=Spackages, MoreArgs=list(quietly=TRUE))))){
 	
 	
 	country='Iceland'
